@@ -1,6 +1,5 @@
 #include <stdlib.h>
-#include <unistd.h>
-#include <stdio.h>
+#include <stdint.h>
 #include "libc.h"
 #include "atomic.h"
 #include "syscall.h"
